# JSON Canvas

This is a simple library to interact with [JSON Canvas](https://jsoncanvas.org/) using Python

Example usage:
```
color_red = Color("#FF0000")
text_node = TextNode(text="Hello", id="1", type="text", x=10, y=20, width=100, height=50, color=color_red)
```